Crate ohos_native_window_manager_sys

Crate ohos_native_window_manager_sys 

Structs

Input_KeyEvent
Input_MouseEvent
Input_TouchEvent
OH_PixelmapNative
@brief Describes the pixel image information.

Constants

WindowManager_ErrorCode_INVAILD_WINDOW_ID
Invalid window ID.
WindowManager_ErrorCode_OK
Successful.
WindowManager_ErrorCode_SERVICE_ERROR
Service error.

Functions

OH_NativeWindowManager_RegisterKeyEventFilter
@brief Registers a function for filtering multimodal key events.
OH_NativeWindowManager_UnregisterKeyEventFilter
@brief Unregisters a function for filtering multimodal key events.

Type Aliases

OH_NativeWindowManager_KeyEventFilter
@brief Defines a function for filtering multimodal key events. @param keyEvent multimodal key event. For details, see {@link Input_KeyEvent}. @return Returns whether to filter this event. Returning true prevents the window from dispatching it further; Returns false indicates that the event is not intercepted. @since 12
WindowManager_ErrorCode
@brief Enumerates the status codes returned by the window manager interface.