Structs
- Input_
KeyEvent - Input_
Mouse Event - Input_
Touch Event - OH_
Pixelmap Native - @brief Describes the pixel image information.
Constants
- Window
Manager_ Error Code_ INVAILD_ WINDOW_ ID - Invalid window ID.
- Window
Manager_ Error Code_ OK - Successful.
- Window
Manager_ Error Code_ SERVICE_ ERROR - Service error.
Functions
- OH_
Native ⚠Window Manager_ Register KeyEvent Filter - @brief Registers a function for filtering multimodal key events.
- OH_
Native ⚠Window Manager_ Unregister KeyEvent Filter - @brief Unregisters a function for filtering multimodal key events.
Type Aliases
- OH_
Native Window Manager_ KeyEvent Filter - @brief Defines a function for filtering multimodal key events. @param keyEvent multimodal key event. For details, see {@link Input_KeyEvent}. @return Returns whether to filter this event. Returning true prevents the window from dispatching it further; Returns false indicates that the event is not intercepted. @since 12
- Window
Manager_ Error Code - @brief Enumerates the status codes returned by the window manager interface.